
# Google Drive MCP Server

An MCP Server for the Google Drive API.

## Supported Integrations

- AgentR
- API Key (Coming Soon)
- OAuth (Coming Soon)

## Tools

This is automatically generated from OpenAPI schema for the Google Drive API.

## Supported Integrations

This tool can be integrated with any service that supports HTTP requests.

## Tool List

| Tool | Description |
|------|-------------|
| get_drive_info | Get information about the user's Google Drive, including storage quota and user info. |
| list_files | List files in the user's Google Drive. |
| create_file_from_text | Create a new file from text content in Google Drive. |
| upload_a_file | Upload a file to Google Drive from a local binary file. |
| find_folder_id_by_name | Find a folder's ID by its name. |
| create_folder | Create a new folder in Google Drive. |
| get_file | Get metadata for a specific file. |
| delete_file | Delete a file from Google Drive. |



## Usage

- Login to AgentR
- Follow the quickstart guide to setup MCP Server for your client
- Visit Apps Store and enable the Google Drive app
- Restart the MCP Server

### Local Development

- Follow the README to test with the local MCP Server
